<template>
    <el-dialog
        :visible.sync="departmentLocationVisible"
        append-to-body
        :close-on-click-modal="false"
        width="75%"
    >
        <div class="app-container">
            <div class="filter-container">
                <el-input v-model="searchContent" class="filter-item" placeholder="输入机构名称" style="width: 400px;" @keyup.enter.native="queryHandle"/>
                <el-button class="filter-item" type="primary" icon="el-icon-search" @click="queryHandle" />
            </div>
            <div class="table_content">
                <el-table
                    v-loading="listLoading"
                    :key="tableKey"
                    :data="publicSecurityDepartmentList"
                    border
                    fit
                    highlight-current-row
                    style="width: 100%;"
                >
                    <el-table-column label="序号" type="index" align="center" width="60"/>
                    <el-table-column label="级别" prop="level" align="center">
                    </el-table-column>
                    <el-table-column label="机构代码" prop="code" align="center">
                    </el-table-column>
                    <el-table-column label="机构名字" prop="name" align="center">
                    </el-table-column>
                    <el-table-column label="操作" align="center" width="180" class-name="small-padding fixed-width">
                        <template slot-scope="scope">
                            <el-button type="text" @click="updateSecuritySupervisory('修改',scope.row)">选择</el-button>
                        </template>
                    </el-table-column>
                </el-table>
                <br>
                <el-pagination
                    v-show="recordTotal>0"
                    :current-page="currentPage"
                    :page-sizes="[10, 20, 30, 50]"
                    :page-size="pageSize"
                    :total="recordTotal"
                    layout="total, sizes, prev, pager, next, jumper"
                    background
                    style="float:right;"
                    @size-change="handleSizeChange"
                    @current-change="handleCurrentChange"
                />
            </div>
        </div>
    </el-dialog>
</template>

<script>
import { computePageCount} from "../../../../utils";
import { getDepartmentList } from '@/api/enterprise'
export default {
    name: "publicSecurityDepartment",
    data(){
        return{
            tableKey:0,
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            searchContent:'',
            departmentLocationVisible:false,
            publicSecurityDepartmentList:[],
        }
    },
    created(){
        this.getPublicSecurityDepartmentList()
    },
    methods:{
        showPublicSecurityDepartment(){
            this.departmentLocationVisible = true
            this.getPublicSecurityDepartmentList()
        },
        async getPublicSecurityDepartmentList(){
            const params = {}
            params['pageIndex'] = this.currentPage
            params['pageSize'] = this.pageSize
            let res = await getDepartmentList(params,{name:this.searchContent})
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.publicSecurityDepartmentList = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
        },
        refreshHandle(){

        },
        queryHandle(){
            this.getPublicSecurityDepartmentList()
        },
        updateSecuritySupervisory(title,value){
            this.$emit('getinfo',value.name)
            this.departmentLocationVisible = false
        },
        handleSizeChange: function(val) {
            this.pageSize = val
            this.currentPage = 1
            this.getPublicSecurityDepartmentList()
        },
        handleCurrentChange: function(val) {
            this.currentPage = val
            this.getPublicSecurityDepartmentList()
        },
    }
}
</script>

<style scoped>

</style>
